summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/formsettingsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/formsettingsimpl.cpp')
-rw-r--r--kdevdesigner/designer/formsettingsimpl.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kdevdesigner/designer/formsettingsimpl.cpp b/kdevdesigner/designer/formsettingsimpl.cpp
index edbb8134..2878d62d 100644
--- a/kdevdesigner/designer/formsettingsimpl.cpp
+++ b/kdevdesigner/designer/formsettingsimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -40,11 +40,11 @@
#include <tqspinbox.h>
#include <tqcheckbox.h>
-FormSettings::FormSettings( TQWidget *parent, FormWindow *fw )
- : FormSettingsBase( parent, 0, TRUE ), formwindow( fw )
+FormSettings::FormSettings( TQWidget *tqparent, FormWindow *fw )
+ : FormSettingsBase( tqparent, 0, TRUE ), formwindow( fw )
{
connect( buttonHelp, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
- MetaDataBase::MetaInfo info = MetaDataBase::metaInfo( fw );
+ MetaDataBase::MetaInfo info = MetaDataBase::metaInfo( TQT_TQOBJECT(fw) );
if ( info.classNameChanged && !info.className.isEmpty() )
editClassName->setText( info.className );
else
@@ -52,8 +52,8 @@ FormSettings::FormSettings( TQWidget *parent, FormWindow *fw )
editComment->setText( info.comment );
editAuthor->setText( info.author );
- editClassName->setValidator( new AsciiValidator( TQString( ":" ), editClassName ) );
- editPixmapFunction->setValidator( new AsciiValidator( TQString( ":" ), editPixmapFunction ) );
+ editClassName->setValidator( new AsciiValidator( TQString( ":" ), TQT_TQOBJECT(editClassName) ) );
+ editPixmapFunction->setValidator( new AsciiValidator( TQString( ":" ), TQT_TQOBJECT(editPixmapFunction) ) );
if ( formwindow->savePixmapInline() )
radioPixmapInline->setChecked( TRUE );
@@ -63,10 +63,10 @@ FormSettings::FormSettings( TQWidget *parent, FormWindow *fw )
radioPixmapFunction->setChecked( TRUE );
editPixmapFunction->setText( formwindow->pixmapLoaderFunction() );
radioProjectImageFile->setEnabled( !fw->project()->isDummy() );
- spinSpacing->setValue( formwindow->layoutDefaultSpacing() );
- spinMargin->setValue( formwindow->layoutDefaultMargin() );
- editSpacingFunction->setValidator( new AsciiValidator( TQString( ":" ), editSpacingFunction ) );
- editMarginFunction->setValidator( new AsciiValidator( TQString( ":" ), editMarginFunction ) );
+ spinSpacing->setValue( formwindow->tqlayoutDefaultSpacing() );
+ spinMargin->setValue( formwindow->tqlayoutDefaultMargin() );
+ editSpacingFunction->setValidator( new AsciiValidator( TQString( ":" ), TQT_TQOBJECT(editSpacingFunction) ) );
+ editMarginFunction->setValidator( new AsciiValidator( TQString( ":" ), TQT_TQOBJECT(editMarginFunction) ) );
checkLayoutFunctions->setChecked( formwindow->hasLayoutFunctions() );
editSpacingFunction->setText( formwindow->spacingFunction() );
editMarginFunction->setText( formwindow->marginFunction() );
@@ -79,17 +79,17 @@ void FormSettings::okClicked()
info.classNameChanged = info.className != TQString( formwindow->name() );
info.comment = editComment->text();
info.author = editAuthor->text();
- MetaDataBase::setMetaInfo( formwindow, info );
+ MetaDataBase::setMetaInfo( TQT_TQOBJECT(formwindow), info );
formwindow->commandHistory()->setModified( TRUE );
if ( formwindow->savePixmapInline() ) {
- MetaDataBase::clearPixmapArguments( formwindow );
- MetaDataBase::clearPixmapKeys( formwindow );
+ MetaDataBase::clearPixmapArguments( TQT_TQOBJECT(formwindow) );
+ MetaDataBase::clearPixmapKeys( TQT_TQOBJECT(formwindow) );
} else if ( formwindow->savePixmapInProject() ) {
- MetaDataBase::clearPixmapArguments( formwindow );
+ MetaDataBase::clearPixmapArguments( TQT_TQOBJECT(formwindow) );
} else {
- MetaDataBase::clearPixmapKeys( formwindow );
+ MetaDataBase::clearPixmapKeys( TQT_TQOBJECT(formwindow) );
}
if ( radioPixmapInline->isChecked() ) {
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the